@@ -45,7 +45,12 @@ def get_ansible_bucket_name(client: SAMLClient) -> str:
 
 
 def get_default_ansible_bucket_name(client: SAMLClient) -> str:
-    return f"{BUCKET_PREFIX}{get_identity(client)['Account']}"
+    account = get_identity(client)["Account"]
+    return f"{BUCKET_PREFIX}{account}"
+
+
+def get_ansible_ssh_profile(client: SAMLClient):
+    return f"{ANSIBLE_SSH_PROFILE}-{client.resource}"
 
 
 def aws_ssm_connection_plugin() -> Path:
@@ -67,7 +72,7 @@ def ansible_connection_plugins_value() -> str:
 
 
 def ansible_profile_proxy(client):
-    return client.clone(klass=AwsProfile, resource=ANSIBLE_SSH_PROFILE)
+    return client.clone(klass=AwsProfile, resource=get_ansible_ssh_profile(client))
 
 
 def sym_subcommand(client, subcommand, args="") -> str:
@@ -133,7 +138,7 @@ def get_send_command_args(client: SAMLClient):
         "ansible_aws_ssm_bucket": bucket_name,
         "ansible_aws_ssm_host_cmd": sym_host_to_instance_cmd,
         "ansible_aws_ssm_region": BUCKET_REGION,
-        "ansible_aws_ssm_profile": ANSIBLE_SSH_PROFILE,
+        "ansible_aws_ssm_profile": get_ansible_ssh_profile(client),
     }
     return " ".join(f"{k}='{v}'" for k, v in extra_vars.items())
 
@@ -180,8 +185,7 @@ def run_ansible(
 
     if client.log_dir:
         envs["ANSIBLE_LOG_PATH"] = str(Tee.path_for_fd(client.log_dir, "ansible"))
-
-    client.write_creds(path=AwsCredentialsPath, profile=ANSIBLE_SSH_PROFILE)
+    client.write_creds(path=AwsCredentialsPath, profile=get_ansible_ssh_profile(client))
 
     if ansible_aws_profile:
         ansible_client = client.clone(klass=AwsProfile, resource=ansible_aws_profile)
