@@ -31,6 +31,10 @@ def sym_config_file(file_name: str) -> Path:
     return (xdg_config_home() / _Config.dir_name / file_name).resolve()
 
 
+def get_dir_name() -> str:
+    return _Config.dir_name
+
+
 class SymConfigFile:
     def __init__(self, *, file_name: str, uid_scope: bool = True, **dependencies):
         path = Path()
