@@ -55,42 +55,55 @@ LaunchDarklyParams: OrgParams = {
             arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
             ansible_bucket="launchdarkly-sym-ansible-staging",
         ),
-        # "production-dr": Profile(
-        #     display_name="Production DR",
-        #     region="us-east-1",
-        #     arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-dr",
-        #     ansible_bucket="launchdarkly-sym-ansible-dr",
-        #     aliases=["dr", "production_dr"],
-        # ),
+        "dr": Profile(
+            display_name="DR",
+            region="us-east-1",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-dr",
+            ansible_bucket="launchdarkly-sym-ansible-dr",
+            aliases=["production_dr"],
+        ),
+        "dev": Profile(
+            display_name="Dev",
+            region="us-east-1",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-dev",
+            ansible_bucket="launchdarkly-sym-ansible-dev",
+        ),
+        "shared-services": Profile(
+            display_name="Shared Services",
+            region="us-east-1",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-shared-services",
+            ansible_bucket="launchdarkly-sym-ansible-shared-services",
+            aliases=["shared_services"],
+        ),
         "catamorphic": Profile(
             display_name="Catamorphic",
             region="us-east-1",
             arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic",
             ansible_bucket="launchdarkly-sym-ansible-catamorphic",
         ),
-        # "catamorphic-dr": Profile(
-        #     display_name="Catamorphic DR",
-        #     region="us-east-1",
-        #     arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic",
-        #     ansible_bucket="launchdarkly-sym-ansible-catamorphic-dr",
-        #     aliases=["catamorphic_dr"],
-        # ),
+        "catamorphic-dr": Profile(
+            display_name="Catamorphic DR",
+            region="us-east-1",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic-dr",
+            ansible_bucket="launchdarkly-sym-ansible-catamorphic-dr",
+            aliases=["catamorphic_dr"],
+        ),
         "prod-intuit": Profile(
-            display_name="Prod: Intuit",
+            display_name="Intuit: Prod",
             region="us-west-2",
             arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-production",
             ansible_bucket="launchdarkly-sym-ansible-prod-intuit",
             aliases=["production-intuit", "intuit_production", "intuit_production_use2"],
         ),
-        # "prod-intuit-dr": Profile(
-        #     display_name="Prod: Intuit",
-        #     region="us-west-2",
-        #     arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-production",
-        #     ansible_bucket="launchdarkly-sym-ansible-prod-intuit-dr",
-        #     aliases=["production-intuit-dr", "intuit_production_dr"]
-        # ),
+        "intuit-dr": Profile(
+            display_name="Intuit: DR",
+            region="us-west-2",
+            arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-intuit-dr",
+            ansible_bucket="launchdarkly-sym-ansible-intuit-dr",
+            aliases=["intuit_dr"],
+        ),
         "staging-intuit": Profile(
-            display_name="Staging: Intuit",
+            display_name="Intuit: Staging",
             region="us-west-2",
             arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-staging",
             ansible_bucket="launchdarkly-sym-ansible-staging-intuit",
