@@ -1,6 +1,6 @@
 from getpass import getuser
 from os import uname
-from typing import Optional
+from typing import Dict, Optional
 from uuid import uuid4
 
 import analytics
@@ -31,24 +31,31 @@ def _identity_kwargs():
 def _skip(global_options: Optional["GlobalOptions"]):
     if not Config.is_logged_in():
         return True
+    if Config.is_sym():
+        return True
     if global_options:
         return global_options.disable_analytics
 
     return False
 
 
+def _augment_properties(properties) -> Dict[str, str]:
+    properties["username"] = getuser()
+
+    for attr in ("org", "email"):
+        try:
+            properties[attr] = Config.instance()[attr]
+        except KeyError:
+            pass
+
+    return properties
+
+
 def identify(global_options: Optional["GlobalOptions"] = None):
     if _skip(global_options):
         return
 
-    traits = {"username": getuser()}
-
-    for attr in ("org", "email"):
-        try:
-            traits[attr] = Config.instance()[attr]
-        except KeyError:
-            pass
-
+    traits = _augment_properties({})
     kwargs = _identity_kwargs()
     analytics.identify(traits=traits, **kwargs)
     if "user_id" in kwargs:
@@ -59,4 +66,8 @@ def track(event, global_options: Optional["GlobalOptions"] = None, **properties)
     if _skip(global_options):
         return
 
-    analytics.track(event=event, properties=properties, **_identity_kwargs())
+    analytics.track(
+        event=event,
+        properties=_augment_properties(properties),
+        **_identity_kwargs(),
+    )
