@@ -15,6 +15,7 @@ import requests
 from semver import VersionInfo
 
 from .config import Config
+from .contexts import push_env
 from .os import has_command, reset_fds
 
 REQ_TIMEOUT = 1
@@ -147,8 +148,15 @@ class SymUpdater:
             self._log(f"{e.returncode}: {e.stderr or e.stdout}", debug=True, fg="red")
             return None
 
-    def _update_with_checked_command(self, command: Sequence[str]):
-        return bool(self._update_with_command(command, check=True, capture_output=True))
+    def _update_with_checked_command(self, command: Sequence[str], **kwargs):
+        return bool(
+            self._update_with_command(
+                command,
+                check=True,
+                capture_output=True,
+                **kwargs,
+            )
+        )
 
     def update_pipx(self) -> bool:
         self._log(
@@ -164,9 +172,19 @@ class SymUpdater:
             f"Using brew. You can also manually run `brew upgrade {Config.get_dir_name()}`.",
             fg="bright_black",
         )
-        return self._update_with_checked_command(
-            ["brew", "upgrade", Config.get_dir_name()]
-        )
+        with push_env("HOMEBREW_NO_AUTO_UPDATE", "1"):
+            res = self._update_with_command(
+                ["brew", "--repo", "symopsio/tap"], capture_output=True
+            )
+            if not res:
+                return False
+
+            return self._update_with_checked_command(
+                ["git", "pull", "origin", "master"],
+                cwd=res.stdout.strip(),
+            ) and self._update_with_checked_command(
+                ["brew", "upgrade", Config.get_dir_name()]
+            )
 
     def update_sitepackage(self) -> bool:
         pip = self.dir.parent.parent.parent / "bin" / "pip"
